#include <windows.h>

BOOL IsUserAdmin(VOID)
/*++ 
Routine Description: This routine returns TRUE if the caller's process 
is a member of the Administrators local group. Caller is NOT expected 
to be impersonating anyone and is expected to be able to open its own 
process and process token. 
Arguments: None. 
Return Value: 
   TRUE - Caller has Administrators local group. 
   FALSE - Caller does not have Administrators local group. --
*/ 
{
BOOL b;
SID_IDENTIFIER_AUTHORITY NtAuthority = SECURITY_NT_AUTHORITY;
PSID AdministratorsGroup; 
b = AllocateAndInitializeSid(
    &NtAuthority,
    2,
    SECURITY_BUILTIN_DOMAIN_RID,
    DOMAIN_ALIAS_RID_ADMINS,
    0, 0, 0, 0, 0, 0,
    &AdministratorsGroup); 
if(b) 
{
    if (!CheckTokenMembership( NULL, AdministratorsGroup, &b)) 
    {
         b = FALSE;
    } 
    FreeSid(AdministratorsGroup); 
}

return(b);
}

/*
Identifier authority   Value   SID string prefix
SECURITY_NT_AUTHORITY  5       S-1-5

Constant                     Value       Identifies
SECURITY_BUILTIN_DOMAIN_RID  (S-1-5-32)  The built-in system domain.

RID                      Identifies
DOMAIN_ALIAS_RID_ADMINS  A local group used for administration of the domain.
*/

